#!/usr/bin/env python3

from l0info_utils import read_packet, read_apid, get_anc_packet_time

__version__ = '2.0.0_2022-08-19'

def l0info_oci(args, fh, output, bDSB):
    # procedure to get start and end times from Level-0 packet files for OCI
    
    status = 0
    if args.verbose:
        print("Reading OCI science data file.")
        
    bSPW = False
    if bDSB:
        # chead = fh.read(64)
        fh.seek(64)
        bSPW = True
    
    # Get first ancillary packet
    apid = 0
    packetLength = 1
    while (apid != 636) and (packetLength > 0):
        try:
            fpacket, packetLength = read_packet(fh, bSPW)
            apid = read_apid(fpacket)
        except:            
            return 100
    
    # If no ancillary packets, rewind and get times from HKT packets
    if fpacket is None: 
        print('No science packets found in file.')
        status = 110
        
        fh.seek(64)
        apid = 0
        packetLength = 1
        while ((apid < 550) or (apid > 750) or (apid == 558)) and (packetLength > 0):
            fpacket, packetLength = read_packet(fh, bSPW)
            apid = read_apid(fpacket)
        
        if fpacket:
            mpacket = fpacket
            try:
                stime = get_anc_packet_time(mpacket[6:12],0,'msec')
                print("start_time=%s" % stime.strftime('%Y-%m-%dT%H:%M:%S.%f'))
                if output:
                    output.write("start_time=%s\n" % stime.strftime('%Y-%m-%dT%H:%M:%S.%f'))
            except:
                return 120

            while fpacket:
                fpacket, packetLength = read_packet(fh, bSPW)
                if fpacket:
                    apid = fpacket[1] + 256*(fpacket[0] % 8)
                else:
                    continue
                if (apid > 550) and (apid < 750):  mpacket = fpacket
            
            etime = get_anc_packet_time(mpacket[6:12],0,'msec')
    
    else:
        try:
            stime = get_anc_packet_time(fpacket,28,'usec')
            print("start_time=%s" % stime.strftime('%Y-%m-%dT%H:%M:%S.%f'))
            if output:
                output.write("start_time=%s\n" % stime.strftime('%Y-%m-%dT%H:%M:%S.%f'))
        except:
            return 120        
    
        packetLength = 1
        while packetLength>0:
            apid = 0
            while (apid != 636) and (packetLength>0):
                fpacket, packetLength = read_packet(fh, bSPW)     
                apid = read_apid(fpacket)
            
            if fpacket:  epacket = fpacket
        
        try:
            etime = get_anc_packet_time(epacket,28,'usec')
        except:
            return 120
    
    print("stop_time=%s" % etime.strftime('%Y-%m-%dT%H:%M:%S.%f'))
    if output:
        output.write("stop_time=%s\n" % etime.strftime('%Y-%m-%dT%H:%M:%S.%f'))

    return status
